@@ -122,7 +122,7 @@ class API:
         self.connect_core = connect_core.API(self.config)
         self._exist_board_list = []
         self._board_info_list = dict()
-        self._ModeratorList = dict()
+        self._moderators = dict()
         # self._last_throw_water_ball_time = 0
         self._thread_id = threading.get_ident()
         self._goto_board_list = []
@@ -428,7 +428,8 @@ class API:
             ptt_bot = PyPtt.API()
             try:
                 # .. login ..
-                ptt_bot.comment(board='Test', comment_type=PyPtt.CommentType.PUSH, comment_content='PyPtt 程式推文測試', index=123)
+                ptt_bot.comment(board='Test', comment_type=PyPtt.CommentType.PUSH, content='Comment by index', index=123)
+                ptt_bot.comment(board='Test', comment_type=PyPtt.CommentType.PUSH, content='Comment by index', aid='17MrayxF')
                 # .. do something ..
             finally:
                 ptt_bot.logout()
